
{% extends "!layout.html" %}

{% block extrahead %}
  {{ super() }}
  <style>
    .custom-banner {
      background: #ffcc00;
      padding: 10px;
      text-align: center;
      font-weight: bold;
    }
  </style>
{% endblock %}

{% block body %}
  <div class="custom-banner">glyphx v1.2.0 — Next-Gen Plotting</div>
  {{ super() }}
{% endblock %}
